==============
Administration
==============

The user plugin provides support for user authentication, login forms and
profiles.

.. toctree::
    :maxdepth: 3
    :caption: Contents:

    overview
    admin-ui/admin-ui

